What is Chiplotle?
==================

*Chiplotle* is an HPGL plotter driver that implements and extends the HPGL (Hewlett-Packard Graphics Language) plotter control language. 
It provides direct control of your HPGL-aware hardware via a standard usb<->serial port interface.
*Chiplotle* is also a general purpose vector drawing library with functions for creating and transforming shapes, which can then be sent directly to your HPGL plotter for printing. 

*Chiplotle* is written and maintained by `Víctor Adán <http://www.victoradan.net>`_ and `Douglas Repetto <http://music.columbia.edu/~douglas>`_.


Find all there is to know about Chiplotle at: http://www.chiplotle.org

